/*
 * Click nbfs://nbhost/SystemFileSystem/Templates/Licenses/license-default.txt to change this license
 */

package com.jcg.ldapapicnextractor;

import java.io.FileInputStream;
import java.security.cert.CertificateFactory;
import java.security.cert.X509Certificate;
import javax.naming.ldap.LdapName;
import javax.naming.ldap.Rdn;


/**
 *
 * @author omozegieaziegbe
 */
public class LDAPApiCNExtractor {

    // Method to load an X.509 certificate from a file
    public static X509Certificate loadCertificate(String filePath) throws Exception {
        try (FileInputStream fis = new FileInputStream(filePath)) {
            CertificateFactory cf = CertificateFactory.getInstance("X.509");
            return (X509Certificate) cf.generateCertificate(fis);
        }
    }

    // Method to extract the CN from the certificate's subject DN
    public static String extractCN(X509Certificate certificate) throws Exception {
        // Get the subject DN from the certificate
        String subjectDN = certificate.getSubjectX500Principal().getName();

        // Parse the DN using JNDI's LdapName class
        LdapName ldapName = new LdapName(subjectDN);

        // Iterate through the RDNs to find the CN
        for (Rdn rdn : ldapName.getRdns()) {
            if ("CN".equalsIgnoreCase(rdn.getType())) {
                return rdn.getValue().toString();
            }
        }

        // If no CN is found, throw an exception
        throw new Exception("CN not found in Subject DN");
    }

    public static void main(String[] args) {
        try {
            // Load the certificate from a file
            X509Certificate certificate = loadCertificate("src/main/resources/javacodegeeks.com.cer");

            // Extract and print the CN
            String cn = extractCN(certificate);
            System.out.println("CN: " + cn);
        } catch (Exception e) {
        }
    }
}
