/*
 * Click nbfs://nbhost/SystemFileSystem/Templates/Licenses/license-default.txt to change this license
 */
package com.jcg.regularexpressionscnextractor;

import java.io.FileInputStream;
import java.security.cert.CertificateFactory;
import java.security.cert.X509Certificate;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 *
 * @author omozegieaziegbe
 */
public class RegularExpressionsCNExtractor {

    // Loading the Certificate
    public static X509Certificate loadCertificate(String filePath) throws Exception {
        try (FileInputStream fis = new FileInputStream(filePath)) {
            CertificateFactory cf = CertificateFactory.getInstance("X.509");
            return (X509Certificate) cf.generateCertificate(fis);
        }
    }

    // Extracting CN with Regular Expressions
    public static String extractCN(X509Certificate certificate) throws Exception {
        String subjectDN = certificate.getSubjectX500Principal().getName();
        String cn = null;

        Pattern pattern = Pattern.compile("CN=([^,]+)");
        Matcher matcher = pattern.matcher(subjectDN);

        if (matcher.find()) {
            cn = matcher.group(1);
        } else {
            throw new Exception("CN not found in Subject DN");
        }

        return cn;
    }

    public static void main(String[] args) throws Exception {

        X509Certificate certificate = loadCertificate("src/main/resources/javacodegeeks.com.cer");
        String cn = extractCN(certificate);
        System.out.println("Common Name: " + cn);

    }
}
